Learn R Programming

FishPhyloMaker (version 0.2.0)

neotropical_comm: Abundance of stream fish species in Parana and Paraguay streams

Description

A dataset containing the abundance of stream fish species distributed in streams of Parana and Paraguay river Basins

Usage

neotropical_comm

Arguments

Format

A data frame with 20 rows and 61 variables: