Learn R Programming

FishPhyloMaker (version 0.2.0)

taxon_data_PhyloMaker: Data frame with species names needed to assemble the phylogenetic tree

Description

A data frame that can be directly used in FishPhyloMaker to obtain a phylogenetic tree

Usage

taxon_data_PhyloMaker

Arguments

Format

A data frame with taxonomic classification (species, family and order) of 45 species

References

Species that make up the dataset in the paper published in Neotropical Ichthyology 10.1590/1982-0224-2020-0126