treedata_modif: Internal function to show the number of species from species pool that lacks in phylogeny
Description
Internal function to show the number of species from species pool that lacks in phylogeny
Usage
treedata_modif(phy, data, sort = FALSE, warnings = TRUE)
Arguments
phy
Phylogenetic hypothesis in newick format
data
Data frame with species to be added in tree
sort
Sorting species in alphabetic order